@@ -6,15 +6,25 @@ import sys
 import warnings
 import weakref
 from functools import lru_cache
-from typing import TYPE_CHECKING, Any, Callable, Iterable, Type, TypeVar, cast, overload
-
-from typing_extensions import Literal
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    ClassVar,
+    Iterable,
+    Type,
+    TypeVar,
+    cast,
+    overload,
+)
 
 from ._dataclass_utils import iter_fields
 from ._group import SignalGroup
 from ._signal import Signal
 
 if TYPE_CHECKING:
+    from typing_extensions import Literal
+
     from ._signal import SignalInstance
 
 
@@ -95,7 +105,10 @@ def _check_field_equality(
         ):
             eq_map[name] = np.array_equal
             return _check_field_equality(cls, name, before, after, _fail=False)
-        else:
+        else:  # pragma: no cover
+            # at some point, dask array started hitting in the above condition
+            # so we add explicit casing in _pick_equality_operator
+            # but we keep this fallback just in case
             eq_map[name] = operator.is_
             return _check_field_equality(cls, name, before, after, _fail=True)
 
@@ -103,6 +116,10 @@ def _check_field_equality(
 def _pick_equality_operator(type_: type | None) -> EqOperator:
     """Get the default equality operator for a given type."""
     np = sys.modules.get("numpy", None)
+    if getattr(type_, "__module__", "").startswith("dask"):
+        # for dask, simply check if the values are the same object
+        # this is to avoid accidentally triggering a computation with array_equal
+        return operator.is_
     if np is not None and hasattr(type_, "__array__"):
         return np.array_equal  # type: ignore [no-any-return]
     return operator.eq
@@ -183,7 +200,7 @@ def evented_setattr(signal_group_name: str, super_setattr: SetAttr) -> SetAttr:
 
 @overload
 def evented_setattr(
-    signal_group_name: str, super_setattr: Literal[None] = None
+    signal_group_name: str, super_setattr: Literal[None] | None = None
 ) -> Callable[[SetAttr], SetAttr]:
     ...
 
@@ -373,7 +390,7 @@ class SignalGroupDescriptor:
 
     # map of id(obj) -> SignalGroup
     # cached here in case the object isn't modifiable
-    _instance_map: dict[int, SignalGroup] = {}
+    _instance_map: ClassVar[dict[int, SignalGroup]] = {}
 
     @overload
     def __get__(self, instance: None, owner: type) -> SignalGroupDescriptor:
@@ -406,9 +423,7 @@ class SignalGroupDescriptor:
             # clean up the cache when the instance is deleted
             with contextlib.suppress(TypeError):
                 # mypy says too many attributes for weakref.finalize, but it's wrong.
-                weakref.finalize(  # type: ignore [call-arg]
-                    instance, self._instance_map.pop, obj_id, None
-                )
+                weakref.finalize(instance, self._instance_map.pop, obj_id, None)  # type: ignore [call-arg]  # noqa
 
         return self._instance_map[obj_id]
 
